from __future__ import unicode_literals

from django.db import models
from django.conf import settings
from django.db import IntegrityError, transaction

from eVotUM.Cripto import auditlogs


class AuditLogsManager(models.Manager):
    """ """
    def audit_create(self, event_type, user, object_repr, object_id,
                     object_json_changes, content_type_id,
                     group_content_type_id, group_object_id):
        """
        Creates an entry with auditable capabilities as a
        sequence of log entries represented by 'log entry N - hash1 N'
        """
        # Build the object to save
        audit_entry = self.model(
            event_type=event_type,
            user=user,
            object_id=object_id,
            object_repr=object_repr,
            object_json_changes=object_json_changes,
            group_content_type_id=group_content_type_id,
            group_object_id=group_object_id,
            content_type_id=content_type_id
        )
        # Maintain database consistency
        return self.atomic_save(audit_entry)

    def atomic_save(self, log_object):
        """ Save the entry maintaining the hash consistency """
        try:
            # Clear the existing entry if it exists
            del(log_object.entry_hash)
            with transaction.atomic():
                # Get the last Hash from the DB
                last_hash = ""
                prev_log = self.model.objects.select_for_update().last()
                # Generate the next Hash
                if prev_log is not None:
                    last_hash = prev_log.entry_hash

                entry_hash = auditlogs.generateLogEntryHash(
                    # The entry contents will be the object diff
                    str(log_object.object_json_changes),
                    str(last_hash),
                    str(settings.SECRET_KEY)
                )
                # Set the new hash
                log_object.entry_hash = entry_hash
                # Save the object
                log_object.save()
                return True

        except IntegrityError:
            # If a change was commited after aquiring the lock
            # Re-fetch the most recent entry
            self.atomic_save(log_object)
