from django.test.client import RequestFactory
from django.test import TestCase
from django.template import Context, Template

from evoteusers.models import User
from evotemessages.models import Message


class TemplateTagsTest(TestCase):

    def render_template(self, string, context=None, request=None):
        context = context or {}
        context = Context(context)
        return Template(string).render(context)


class MessagesTagsTest(TemplateTagsTest):

    def setUp(self):
        self.rf = RequestFactory()
        self.rf.user = User.objects.get(pk=1)

    def test_inbox_tag(self):
        template = "{% load messages_tags %}{% inbox_count %}"
        rendered = self.render_template(template, {'request': self.rf})
        self.assertEqual(rendered, "0")

    def test_inbox_tag_with_obj(self):
        template = "{% load messages_tags %}{% inbox_count %}"
        rendered = self.render_template(
            template, {'request': self.rf, 'obj': Message()})
        self.assertEqual(rendered, "0")

    def test_sentbox_tag(self):
        template = "{% load messages_tags %}{% sentbox_count %}"
        rendered = self.render_template(template, {'request': self.rf})
        self.assertEqual(rendered, "0")

    def test_sentbox_tag_with_obj(self):
        template = "{% load messages_tags %}{% sentbox_count %}"
        rendered = self.render_template(
            template, {'request': self.rf, 'obj': Message()})
        self.assertEqual(rendered, "0")

    def test_archived_tag(self):
        template = "{% load messages_tags %}{% archived_count %}"
        rendered = self.render_template(template, {'request': self.rf})
        self.assertEqual(rendered, "0")

    def test_archived_tag_with_obj(self):
        template = "{% load messages_tags %}{% archived_count %}"
        rendered = self.render_template(
            template, {'request': self.rf, 'obj': Message()})
        self.assertEqual(rendered, "0")

    def test_nested_url(self):
        template = "{% load messages_tags %}{% nested_url 'messages-received' \
            %}"
        rendered = self.render_template(template)
        self.assertEqual(rendered, "/en/voters/messages/received/")
